package cl.tefix.ventas.GestionRutas.empresas.tipos;

import cl.tefix.ventas.GestionRutas.*;
import java.sql.*;
import java.util.*;

public class TipoEmpresa {
  private int codigo;
  private String nombre;

  /** crea un objeto a partir del cdigo*/
  public TipoEmpresa(int codigo) throws Exception {
    try{
      String select = "select * from tipo_emp where cod_tipo=?";
      PreparedStatement ps = GestionRutas.getConexion().prepareStatement(select);
      ps.setInt(1,codigo);
      ResultSet rs = ps.executeQuery();
      if(rs.next()){
        this.codigo = codigo;
        this.nombre = rs.getString(2);
      }else
        throw new Exception("TipoEmpresa: No existe un Tipo de Empresa con Dicho Cdigo");
      rs.close();
      ps.close();
//      System.out.println("TipoEmpresa(): Cerr el rs y el ps");
    } catch(SQLException e){
      throw new Exception("TipoEmpresa: No se puede cargar el tipo de Empresa: " + e.getMessage());
    }
  }

  /** crea un objeto a partir del nombre.*/
  public TipoEmpresa(String nombre) throws Exception {
    try{
      String select = "select * from tipo_emp where tipo_emp='?'";
      PreparedStatement ps = GestionRutas.getConexion().prepareStatement(select);
      ps.setString(1,nombre);
      ResultSet rs = ps.executeQuery();
      if(rs.next()){
        this.nombre = nombre;
        this.codigo = rs.getInt(1);
      }else
        throw new Exception("TipoEmpresa: No existe un Tipo de Empresa con Dicho Nombre");
      rs.close();
      ps.close();
//      System.out.println("TipoEmpresa(): Cerr el rs y el ps");
    } catch(SQLException e){
      throw new Exception("TipoEmpresa: No se puede cargar el tipo de Empresa: " + e.getMessage());
    }
  }

  /** Obtiene el cdigo del tipo de Empresa */
  public int getCodigo(){
    return codigo;
  }

  /** Obtiene el nombre del tipo de Empresa */
  public String getNombre(){
    return nombre;
  }

  /** Permite cambiar el nombre al tipo de Empresa */
  public void setNombre(String nombre) throws Exception {
    try{
      cambiarNombre(nombre);
      this.nombre = nombre;
    }catch(SQLException e){
      throw new Exception("No se cambiar el nombre al tipo de Empresa: " + e.getMessage());
    }
  }

  private void cambiarNombre(String nombre) throws SQLException {
    String update = "update tipo_emp set tipo_emp='?' where cod_tipo=?";
    PreparedStatement ps = GestionRutas.getConexion().prepareStatement(update);
    ps.setString(1, nombre);
    ps.setInt(2, this.codigo);
    ps.execute();
    ps.close();
  }

//Mtodos Estticos
  /** Permite crear un nuevo tipo de Empresa */
  public static void crearTipo(String nombre) throws Exception {
    try{
      String insert = "insert into tipo_emp(tipo_emp) values(?)";
      PreparedStatement ps = GestionRutas.getConexion().prepareStatement(insert);
      ps.setString(1,nombre);
      ps.execute();
      ps.close();
    }catch(SQLException e){
      throw new Exception("No se puede crear el tipo de Empresa: " + e.getMessage());
    }
  }

  /** Permite eliminar un tipo de Empresa */
  public static void borrarTipo(String nombre) throws Exception {
    try{
      String delete = "delete from tipo_emp where tipo_emp='?'";
      PreparedStatement ps = GestionRutas.getConexion().prepareStatement(delete);
      ps.setString(1,nombre);
      ps.execute();
      ps.close();
    } catch(SQLException e){
      throw new Exception("No se puede eliminar el tipo de Empresa: " + e.getMessage());
    }
  }

  /** devuelve el todos los tipos de empresas que existen */
  public static Collection getAllNames() throws Exception{
    Vector VectorDatos = new Vector();
    try{
      String select = "select * from tipo_emp";
      Statement stmt = GestionRutas.getConexion().createStatement();
      ResultSet rs = stmt.executeQuery(select);
      while(rs.next()){
        VectorDatos.add(new String(rs.getString(2)));
      }
      rs.close();
      stmt.close();
//      System.out.println("getAllNames(): Cerr el rs y el ps");
    } catch(SQLException e){
      throw new Exception("No se pueden Obtener los Tipos de Empresa: " + e.getMessage());
    }
    return VectorDatos;
  }

}
